@@ -11,10 +11,10 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-#
-# ================================================================================================
 
-__version__ = '0.1.3'
+from dwavebinarycsp import __version__
+
+# keep description, author and author email up to date with setup.cfg
 __author__ = 'D-Wave Systems Inc.'
-__authoremail__ = 'acondello@dwavesys.com'
+__authoremail__ = 'tools@dwavesys.com'
 __description__ = 'Solves constraints satisfaction problems with binary quadratic model samplers'
